﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using InvoiceManagerWeb.Models;

namespace InvoiceManagerWeb.Controllers
{
    public class InvoicesController : Controller
    {
        private InvoiceContext db = new InvoiceContext();

        //
        // GET: /Invoices/

        public ActionResult Index()
        {
            return View(db.Invoice.ToList());
        }

        //
        // GET: /Invoices/Details/5

        public ActionResult Details(int id = 0)
        {
            Invoice invoice = db.Invoice.Find(id);
            if (invoice == null)
            {
                return HttpNotFound();
            }
            ViewBag.InfoSubscriber = Invoice.getPerson(invoice.SubscriberID);
            ViewBag.InfoSupplier = Invoice.getPerson(invoice.SupplierID);

            ViewBag.InfoItem1 = Invoice.getPerson(invoice.Item1);
            ViewBag.InfoItem2 = Invoice.getPerson(invoice.Item2);
            ViewBag.InfoItem3 = Invoice.getPerson(invoice.Item3);
            ViewBag.InfoItem4 = Invoice.getPerson(invoice.Item4);
            ViewBag.InfoItem5 = Invoice.getPerson(invoice.Item5);


            return View(invoice);
        }

        //
        // GET: /Invoices/Create

        public ActionResult Create()
        {
            return View();
        }

        //
        // POST: /Invoices/Create

        [HttpPost]
        [ValidateAntiForgeryToken]
        public ActionResult Create(Invoice invoice)
        {
            if (ModelState.IsValid)
            {
                db.Invoice.Add(invoice);
                db.SaveChanges();
                return RedirectToAction("Index");
            }

            return View(invoice);
        }

        //
        // GET: /Invoices/Edit/5

        public ActionResult Edit(int id = 0)
        {
            Invoice invoice = db.Invoice.Find(id);
            if (invoice == null)
            {
                return HttpNotFound();
            }
            return View(invoice);
        }

        //
        // POST: /Invoices/Edit/5

        [HttpPost]
        [ValidateAntiForgeryToken]
        public ActionResult Edit(Invoice invoice)
        {
            if (ModelState.IsValid)
            {
                db.Entry(invoice).State = EntityState.Modified;
                db.SaveChanges();
                return RedirectToAction("Index");
            }
            return View(invoice);
        }

        //
        // GET: /Invoices/Delete/5

        public ActionResult Delete(int id = 0)
        {
            Invoice invoice = db.Invoice.Find(id);
            if (invoice == null)
            {
                return HttpNotFound();
            }
            return View(invoice);
        }

        //
        // POST: /Invoices/Delete/5

        [HttpPost, ActionName("Delete")]
        [ValidateAntiForgeryToken]
        public ActionResult DeleteConfirmed(int id)
        {
            Invoice invoice = db.Invoice.Find(id);
            db.Invoice.Remove(invoice);
            db.SaveChanges();
            return RedirectToAction("Index");
        }

        public ActionResult Paid(int id = 0)
        {
            Invoice invoice = db.Invoice.Find(id);
            if (invoice == null)
            {
                return HttpNotFound();
            }
            invoice.Paid = true;
            db.SaveChanges();
            return RedirectToAction("Index");
        }

        public ActionResult UnPaid(int id = 0)
        {
            Invoice invoice = db.Invoice.Find(id);
            if (invoice == null)
            {
                return HttpNotFound();
            }
            invoice.Paid = false;
            db.SaveChanges();
            return RedirectToAction("Index");
        }

        protected override void Dispose(bool disposing)
        {
            db.Dispose();
            base.Dispose(disposing);
        }
    }
}