﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;


using System.Data.Entity;
using System.ComponentModel.DataAnnotations;
using System.Web.Mvc;
using System.ComponentModel;


namespace InvoiceManagerWeb.Models
{
    /// <summary>
    /// Výčtový typ pro typ faktury
    /// </summary>
    public enum TypeInv { vydana, prijata }

    /// <summary>
    /// Datová třída reprezentující fakturu
    /// </summary>
    public class Invoice
    {
        /// <summary>
        /// Jedinečné ID faktruy
        /// </summary>
        [Display(Name = "ID")]
        public int ID { get; set; }

        /// <summary>
        /// Typ položky - Vydaná/Přijatá
        /// </summary>
        [Display(Name = "Typ")]
        public TypeInv Type { get; set; }

        /// <value>
        /// Odběratel
        /// </value>
        [Display(Name = "Odběratel")]
        public int SubscriberID { get; set; }

        /// <value>
        /// Dodavatel
        /// </value>
        [Display(Name = "Dodavatel")]
        public int SupplierID { get; set; }


        /// <value>
        /// Položka 1
        /// </value>
        [Display(Name = "Položka 1")]
        public int Item1 { get; set; }
        /// <value>
        /// Položka 2
        /// </value>
        [Display(Name = "Položka 2")]
        public int Item2 { get; set; }
        /// <value>
        /// Položka 3
        /// </value>
        [Display(Name = "Položka 3")]
        public int Item3 { get; set; }
        /// <value>
        /// Položka 4
        /// </value>
        [Display(Name = "Položka 4")]
        public int Item4 { get; set; }
        /// <value>
        /// Položka 5
        /// </value>
        [Display(Name = "Položka 15")]
        public int Item5 { get; set; }
        
        
        /// <summary>
        /// Datum vytvoření
        /// </summary>
        [DataType(DataType.Date)]
        [Display(Name = "Datum vytvoření")]
        [DisplayFormat(DataFormatString = "{0:yyyy-MM-dd}", ApplyFormatInEditMode = true)]
        public DateTime Created { get; set; }

        /// <summary>
        /// Datum splatnosti
        /// </summary>
        [DataType(DataType.Date)]
        [Display(Name = "Datum splatnosti")]
        [DisplayFormat(DataFormatString = "{0:yyyy-MM-dd}", ApplyFormatInEditMode = true)]
        public DateTime DueDate { get; set; }

        /// <summary>
        /// Označení pro zaplacené faktury
        /// </summary>
        [Display(Name = "Zaplacená")]
        [DefaultValue(false)]
        public bool Paid { get; set; }

        /// <summary>
        /// Řetězec vypisující stav zaplacení
        /// </summary>
        public string PaidString
        {
            get 
            {
                if (Paid == true)
                    return "ANO";
                else
                    return "NE";
            }
        }

        /// <summary>
        /// Řetězec vypisující typ faktury
        /// </summary>
        public string TypeString
        {
            get
            {
                if (Type == TypeInv.vydana)
                    return "Vydaná";
                else
                    return "Přijatá";
            }
        }

        /// <summary>
        /// Metoda vyhledá osobu a vrátí její celé jméno
        /// </summary>
        public static string getPerson(int ID)
        {

            if (ID == 0)
                return "Neuvedeno";

            PersonContext db = new PersonContext();
            Person person = db.Persons.Find(ID);

            if (person == null)
                return "Neuvedeno";

            return person.CompleteName;
        }

        /// <summary>
        /// Metoda vyhledá položku a vrátí její celé jméno
        /// </summary>
        public static string getItem(int ID)
        {
            if (ID == 0)
                return "Neuvedeno";

            ItemContext db = new ItemContext();
            Item item = db.Items.Find(ID);

            if (item == null)
                return "Neuvedeno";

            return item.Description;
        }
    }

    /// <summary>
    /// Databázový kontext pro faktury
    /// </summary>
    public class InvoiceContext : DbContext
    {
        public DbSet<Invoice> Invoice { get; set; }
    }
}